@@ -39,9 +39,10 @@ import sys
 
 from distutils.version import LooseVersion
 
-from easybuild.framework.easyblock import EasyBlock, get_class
+from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig.constants import constant_documentation
 from easybuild.framework.easyconfig.default import convert_to_help
+from easybuild.framework.easyconfig.easyconfig import get_easyblock_class
 from easybuild.framework.easyconfig.format.pyheaderconfigobj import build_easyconfig_constants_dict
 from easybuild.framework.easyconfig.licenses import license_documentation
 from easybuild.framework.easyconfig.templates import template_documentation
@@ -58,7 +59,7 @@ from easybuild.tools.ordereddict import OrderedDict
 from easybuild.tools.toolchain.utilities import search_toolchain
 from easybuild.tools.repository import avail_repositories
 from easybuild.tools.version import this_is_easybuild
-from vsc import fancylogger
+from vsc.utils import fancylogger
 from vsc.utils.generaloption import GeneralOption
 from vsc.utils.missing import any
 
@@ -144,18 +145,25 @@ class EasyBuildOptions(GeneralOption):
         descr = ("Override options", "Override default EasyBuild behavior.")
 
         opts = OrderedDict({
+            'allow-modules-tool-mismatch': ("Allow mismatch of modules tool and definition of 'module' function",
+                                            None, 'store_true', False),
             'deprecated': ("Run pretending to be (future) version, to test removal of deprecated code.",
                            None, 'store', None),
             'easyblock': ("easyblock to use for processing the spec file or dumping the options",
                           None, 'store', None, 'e', {'metavar': 'CLASS'}),
             'experimental': ("Allow experimental code (with behaviour that can be changed or removed at any given time).",
                              None, 'store_true', False),
+            'group': ("Group to be used for software installations (only verified, not set)", None, 'store', None),
             'ignore-osdeps': ("Ignore any listed OS dependencies", None, 'store_true', False),
             'oldstyleconfig':   ("Look for and use the oldstyle configuration file.",
                                  None, 'store_true', True),
             'pretend': (("Does the build/installation in a test directory located in $HOME/easybuildinstall"),
                          None, 'store_true', False, 'p'),
+            'set-gid-bit': ("Set group ID bit on newly created directories", None, 'store_true', False),
+            'sticky-bit': ("Set sticky bit on newly created directories", None, 'store_true', False),
             'skip-test-cases': ("Skip running test cases", None, 'store_true', False, 't'),
+            'umask': ("umask to use (e.g. '022'); non-user write permissions on install directories are removed",
+                      None, 'store', None),
         })
 
         self.log.debug("override_options: descr %s opts %s" % (descr, opts))
@@ -312,6 +320,11 @@ class EasyBuildOptions(GeneralOption):
             stop_msg.append('--try-toolchain requires NAME,VERSION (given %s)' %
                             (','.join(self.options.try_toolchain)))
 
+        if self.options.umask:
+            umask_regex = re.compile('^[0-7]{3}$')
+            if not umask_regex.match(self.options.umask):
+                stop_msg.append("--umask value should be 3 digits (0-7) (regex pattern '%s')" % umask_regex.pattern)
+
         if len(stop_msg) > 0:
             indent = " "*2
             stop_msg = ['%s%s' % (indent, x) for x in stop_msg]
@@ -424,7 +437,7 @@ class EasyBuildOptions(GeneralOption):
         """
         Print the available easyconfig parameters, for the given easyblock.
         """
-        app = get_class(self.options.easyblock)
+        app = get_easyblock_class(self.options.easyblock)
         extra = app.extra_options()
         mapping = convert_to_help(extra, has_default=False)
         if len(extra) > 0:
